==> typegram-0.0.1-py3-none-any.whl: typegram/api/functions/messages/getEmojiKeywords.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class GetEmojiKeywords(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``35A0E062``

lang_code (``str``):
                    N/A
                
    Returns:
        :obj:`EmojiKeywordsDifference<typegram.api.ayiin.EmojiKeywordsDifference>`
    """

    __slots__: List[str] = ["lang_code"]

    ID = 0x35a0e062
    QUALNAME = "functions.functions.EmojiKeywordsDifference"

    def __init__(self, *, lang_code: str) -> None:
        
                self.lang_code = lang_code  # string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "GetEmojiKeywords":
        # No flags
        
        lang_code = String.read(b)
        
        return GetEmojiKeywords(lang_code=lang_code)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.lang_code))
        
        return b.getvalue()

==> typegram-0.0.2-py3-none-any.whl: typegram/api/functions/messages/getEmojiKeywords.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram import api
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class GetEmojiKeywords(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``35A0E062``

lang_code (``str``):
                    N/A
                
    Returns:
        :obj:`EmojiKeywordsDifference<typegram.api.ayiin.EmojiKeywordsDifference>`
    """

    __slots__: List[str] = ["lang_code"]

    ID = 0x35a0e062
    QUALNAME = "functions.messages.getEmojiKeywords"

    def __init__(self, *, lang_code: str) -> None:
        
                self.lang_code = lang_code  # string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "GetEmojiKeywords":
        # No flags
        
        lang_code = String.read(b)
        
        return GetEmojiKeywords(lang_code=lang_code)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.lang_code))
        
        return b.getvalue()
